==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/txt2xtHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "comvert from plainText to XML Table"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define HFDT "regard the first line of plainText file as attribute names"
#define HFDC "regard the first line of plainText file as attribute names"

/*-a*/
#define FNMT "a list of attributes"
#define FNMC "record the list of attributes specified here in the header of xmlTable"

/*-l*/
#define TITT "title"
#define TITC "record the title specified here in the header of xmlTable"

/*-c*/
#define COMT "comment"
#define COMC "record the comment specified here in the header of xmlTable"

/*-I*/
#define IMPT "import filename"
#define IMPC "import header from the other xmlTable file"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command converts a plainText file to an xmlTable file."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  txt2xt -F -i dat.txt -o rsl.xt\n\
  txt2xt -acustomerID,date,brandname,quantity,amount -i dat.txt -o rls.xt\n\
  txt2xt -F -i dat.txt -l sample data -c created for manual use -o rsl.xt\n\
  txt2xt -I header.xt -i dat.txt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2txt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/en/txt2xtHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "convert from plainText to XML Table"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-F*/
#define HFDT "regard the first line of plainText file as attribute names"
#define HFDC "regard the first line of plainText file as attribute names"

/*-a*/
#define FNMT "a list of attributes"
#define FNMC "record the list of attributes specified here in the header of xmlTable"

/*-l*/
#define TITT "title"
#define TITC "record the title specified here in the header of xmlTable"

/*-c*/
#define COMT "comment"
#define COMC "record the comment specified here in the header of xmlTable"

/*-I*/
#define IMPT "import filename"
#define IMPC "import header from the other xmlTable file"

/*-f*/
#define FRCT "ܿΡå"
#define FRCC "ܿΥå򤪤ʤʤإåιܿ˹碌ƽ롣"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command converts a plainText file to an xmlTable file. The three methods to specify attribute names are options -F, -a and -I. When all of -F,-a and -I are specified, the priority is given in the order of -I, -F, -a. When header is imported with -I, all header information such as sort status is imported."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
  txt2xt -F -i dat.txt -o rsl.xt\n\
  txt2xt -a customerID,date,brandname,quantity,amount -i dat.txt -o rls.xt\n\
  txt2xt -F -i dat.txt -l sample data -c created for manual use -o rsl.xt\n\
  txt2xt -I header.xt -i dat.txt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xt2txt,xt2xml,xml2xt"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
